@@ -1,14 +1,10 @@
-from .api.utils import (
+from .api.core import (
     build_definition_table,
     collapse_alleles,
-    combine_results,
-    compute_control_statistics,
-    compute_copy_number,
-    compute_target_depth,
-    create_consolidated_vcf,
-    create_regions_bed,
-    estimate_phase_beagle,
-    filter_samples,
+    has_phenotype,
+    has_score,
+    is_legit_allele,
+    is_target_gene,
     get_default_allele,
     get_function,
     get_paralog,
@@ -16,31 +12,43 @@ from .api.utils import (
     get_ref_allele,
     get_region,
     get_score,
-    has_phenotype,
-    has_score,
-    import_read_depth,
-    import_variants,
-    is_target_gene,
+    get_variant_impact,
+    get_variant_synonyms,
     list_alleles,
     list_functions,
     list_genes,
     list_phenotypes,
     list_variants,
     load_allele_table,
-    load_control_table,
     load_cnv_table,
     load_diplotype_table,
     load_equation_table,
     load_gene_table,
     load_phenotype_table,
     load_variant_table,
-    predict_alleles,
-    predict_cnv,
     predict_phenotype,
     predict_score,
+    sort_alleles,
+)
+
+from .api.utils import (
+    call_phenotypes,
+    combine_results,
+    compute_control_statistics,
+    compare_genotypes,
+    compute_copy_number,
+    compute_target_depth,
+    count_alleles,
+    create_consolidated_vcf,
+    create_regions_bed,
+    estimate_phase_beagle,
+    filter_samples,
+    import_read_depth,
+    import_variants,
+    predict_alleles,
+    predict_cnv,
     prepare_depth_of_coverage,
     print_metadata,
-    sort_alleles,
     test_cnv_caller,
     train_cnv_caller,
 )
@@ -48,6 +56,7 @@ from .api.utils import (
 from .api.plot import (
     plot_bam_copy_number,
     plot_bam_read_depth,
+    plot_cn_af,
     plot_vcf_allele_fraction,
     plot_vcf_read_depth,
 )
