@@ -6,35 +6,33 @@ import fuc
 import pysam
 
 description = f"""
-############################
-# Create consolidated VCF. #
-############################
-
-Usage examples:
-  $ pypgx {fuc.api.common._script_name()} CYP2D6-imported-variants.zip CYP2D6-phased-variants.zip CYP2D6-consolidated-variants.zip
+Create a consolidated VCF file.
 """
 
 def create_parser(subparsers):
     parser = fuc.api.common._add_parser(
         subparsers,
         fuc.api.common._script_name(),
-        help='Create consolidated VCF.',
+        help='Create a consolidated VCF file.',
         description=description,
     )
     parser.add_argument(
         'imported_variants',
         metavar='imported-variants',
-        help='Archive file with the semantic type VcfFrame[Imported].'
+        help='Archive file with the semantic type \n'
+             'VcfFrame[Imported].'
     )
     parser.add_argument(
         'phased_variants',
         metavar='phased-variants',
-        help='Archive file with the semantic type VcfFrame[Phased]'
+        help='Archive file with the semantic type \n'
+             'VcfFrame[Phased].'
     )
     parser.add_argument(
         'consolidated_variants',
         metavar='consolidated-variants',
-        help='Archive file with the semantic type VcfFrame[Consolidated].'
+        help='Archive file with the semantic type \n'
+             'VcfFrame[Consolidated].'
     )
 
 def main(args):
