@@ -6,25 +6,26 @@ import fuc
 import pysam
 
 description = f"""
-###########################################
-# Plot copy number profile with BAM data. #
-###########################################
-
-Usage examples:
-  $ pypgx {fuc.api.common._script_name()} CYP2D6-copy-number.zip
+Plot copy number profile from CovFrame[CopyNumber].
 """
 
 def create_parser(subparsers):
     parser = fuc.api.common._add_parser(
         subparsers,
         fuc.api.common._script_name(),
-        help='Plot copy number profile with BAM data.',
         description=description,
+        help='Plot copy number profile from CovFrame[CopyNumber].',
     )
     parser.add_argument(
         'copy_number',
         metavar='copy-number',
-        help='Archive file with the semantic type CovFrame[CopyNumber].'
+        help='Archive file with the semantic type \n'
+             'CovFrame[CopyNumber].'
+    )
+    parser.add_argument(
+        '--fitted',
+        action='store_true',
+        help='Show the fitted line as well.'
     )
     parser.add_argument(
         '--path',
@@ -41,22 +42,27 @@ def create_parser(subparsers):
         '--ymin',
         metavar='FLOAT',
         type=float,
-        help='Y-axis bottom.'
+        default=0,
+        help='Y-axis bottom (default: -0.3).'
     )
     parser.add_argument(
         '--ymax',
         metavar='FLOAT',
         type=float,
-        help='Y-axis top.'
+        default=6,
+        help='Y-axis top (default: 6.3).'
     )
     parser.add_argument(
-        '--fitted',
-        action='store_true',
-        help='Show the fitted line as well.'
+        '--fontsize',
+        metavar='FLOAT',
+        type=float,
+        default=25,
+        help='Text fontsize (default: 25).'
     )
 
 def main(args):
     plot.plot_bam_copy_number(
-        args.copy_number, path=args.path, samples=args.samples,
-        ymin=args.ymin, ymax=args.ymax, fitted=args.fitted
+        args.copy_number, fitted=args.fitted, path=args.path,
+        samples=args.samples, ymin=args.ymin, ymax=args.ymax,
+        fontsize=args.fontsize
     )
